@@ -49,10 +49,7 @@ sub run($$) {
     for my $arg (@args) {
 	if (exists $proc->{aliases}{$arg}) {
 	    my $command_name = $proc->{aliases}{$arg};
-	    my $cmd_alias_ref = $proc->{commands}{$command_name}{aliases};
-	    my @new_aliases = grep(($arg ne $_), @$cmd_alias_ref);
-	    $proc->{commands}{$command_name}{aliases} = \@new_aliases;
-	    delete $proc->{aliases}{$arg};
+	    $proc->remove_alias($command_name, $arg);
 	    $proc->msg("Alias for ${arg} removed.");
 	} else {
 	    $proc->msg("No alias found for ${arg}.");
