@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org> 
+# Copyright (C) 2011, 2012 Rocky Bernstein <rocky@cpan.org> 
 use strict; use warnings;
 use rlib '../../..';
-use Devel::Trepan::DB::Sub;
+use Devel::Trepan::DB::LineCache; # for map_file
 use Devel::Trepan::Complete;
 
 package Devel::Trepan::CmdProcessor;
@@ -102,7 +102,7 @@ sub frame_setup($$)
 sub filename($)
 {
     my $self = shift;
-    $self->{frame}{file};
+    DB::LineCache::map_file($self->{frame}{file});
 }
 
 sub funcname($)
